//////////////////////////////////////////////////////////////////////////////
// Filename:          D:\pc-colt\d\JOB\SUZAKU_SE\fpga\8_1\ddl\20060623/drivers/opb_sil00_v1_01_a/src/opb_sil00_selftest.c
// Version:           1.01.a
// Description:       Contains a diagnostic self-test function for the opb_sil00 driver
// Date:              Tue Aug 08 13:37:39 2006 (by Create and Import Peripheral Wizard)
//////////////////////////////////////////////////////////////////////////////


/***************************** Include Files *******************************/

#include "opb_sil00.h"

/************************** Constant Definitions ***************************/


/************************** Variable Definitions ****************************/


/************************** Function Definitions ***************************/

/**
 *
 * Run a self-test on the driver/device. Note this may be a destructive test if
 * resets of the device are performed.
 *
 * If the hardware system is not built correctly, this function may never
 * return to the caller.
 *
 * @param   baseaddr_p is the base address of the OPB_SIL00 instance to be worked on.
 *
 * @return
 *
 *    - XST_SUCCESS   if all self-test code passed
 *    - XST_FAILURE   if any self-test code failed
 *
 * @note    Caching must be turned off for this function to work.
 * @note    Self test may fail if data memory and device are not on the same bus.
 *
 */
XStatus OPB_SIL00_SelfTest(void * baseaddr_p)
{
   int     Index;
   Xuint32 baseaddr;
   Xuint8  Reg8Value;
   Xuint16 Reg16Value;
   Xuint32 Reg32Value;
   Xuint64 Reg64Value;

   /*
    * Assert the argument
    */
   XASSERT_NONVOID(baseaddr_p != XNULL);
   baseaddr = (Xuint32) baseaddr_p;

   xil_printf("******************************\n\r");
   xil_printf("* User Peripheral Self Test\n\r");
   xil_printf("******************************\n\n\r");

   /*
    * Write to user logic slave module register(s) and read back
    */
   xil_printf("User logic slave module test...\n\r");
   xil_printf("   - write 1 to slave register 0\n\r");
   OPB_SIL00_mWriteSlaveReg0(baseaddr, 1);
   Reg8Value = OPB_SIL00_mReadSlaveReg0(baseaddr);
   xil_printf("   - read %d from register 0\n\r", Reg8Value);
   if ( Reg8Value != (Xuint8) 1 )
   {
      xil_printf("   - slave register 0 write/read failed\n\r");
      return XST_FAILURE;
   }
   xil_printf("   - write 2 to slave register 1\n\r");
   OPB_SIL00_mWriteSlaveReg1(baseaddr, 2);
   Reg8Value = OPB_SIL00_mReadSlaveReg1(baseaddr);
   xil_printf("   - read %d from register 1\n\r", Reg8Value);
   if ( Reg8Value != (Xuint8) 2 )
   {
      xil_printf("   - slave register 1 write/read failed\n\r");
      return XST_FAILURE;
   }
   xil_printf("   - write 3 to slave register 2\n\r");
   OPB_SIL00_mWriteSlaveReg2(baseaddr, 3);
   Reg8Value = OPB_SIL00_mReadSlaveReg2(baseaddr);
   xil_printf("   - read %d from register 2\n\r", Reg8Value);
   if ( Reg8Value != (Xuint8) 3 )
   {
      xil_printf("   - slave register 2 write/read failed\n\r");
      return XST_FAILURE;
   }
   xil_printf("   - write 4 to slave register 3\n\r");
   OPB_SIL00_mWriteSlaveReg3(baseaddr, 4);
   Reg8Value = OPB_SIL00_mReadSlaveReg3(baseaddr);
   xil_printf("   - read %d from register 3\n\r", Reg8Value);
   if ( Reg8Value != (Xuint8) 4 )
   {
      xil_printf("   - slave register 3 write/read failed\n\r");
      return XST_FAILURE;
   }
   xil_printf("   - write 5 to slave register 4\n\r");
   OPB_SIL00_mWriteSlaveReg4(baseaddr, 5);
   Reg8Value = OPB_SIL00_mReadSlaveReg4(baseaddr);
   xil_printf("   - read %d from register 4\n\r", Reg8Value);
   if ( Reg8Value != (Xuint8) 5 )
   {
      xil_printf("   - slave register 4 write/read failed\n\r");
      return XST_FAILURE;
   }
   xil_printf("   - write 6 to slave register 5\n\r");
   OPB_SIL00_mWriteSlaveReg5(baseaddr, 6);
   Reg8Value = OPB_SIL00_mReadSlaveReg5(baseaddr);
   xil_printf("   - read %d from register 5\n\r", Reg8Value);
   if ( Reg8Value != (Xuint8) 6 )
   {
      xil_printf("   - slave register 5 write/read failed\n\r");
      return XST_FAILURE;
   }
   xil_printf("   - slave register write/read passed\n\n\r");

   /*
    * Enable all possible interrupts and clear interrupt status register(s)
    */
   xil_printf("Interrupt controller test...\n\r");
   Reg32Value = OPB_SIL00_mReadReg(baseaddr, OPB_SIL00_INTR_ISR_OFFSET);
   xil_printf("   - IP (user logic) interrupt status : 0x%08x \n\r", Reg32Value);
   xil_printf("   - clear IP (user logic) interrupt status register\n\r");
   OPB_SIL00_mWriteReg(baseaddr, OPB_SIL00_INTR_ISR_OFFSET, Reg32Value);
   Reg32Value = OPB_SIL00_mReadReg(baseaddr, OPB_SIL00_INTR_DISR_OFFSET);
   xil_printf("   - Device (peripheral) interrupt status : 0x%08x \n\r", Reg32Value);
   xil_printf("   - clear Device (peripheral) interrupt status register\n\r");
   OPB_SIL00_mWriteReg(baseaddr, OPB_SIL00_INTR_DISR_OFFSET, Reg32Value);
   xil_printf("   - enable all possible interrupt(s)\n\r");
   OPB_SIL00_EnableInterrupt(baseaddr_p);
   xil_printf("   - write/read interrupt register passed \n\n\r");

   return XST_SUCCESS;
}
