----------------------------
--dynamic_ctrl.vhd
----------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity dynamic_ctrl is
    Port ( 
        SYS_CLK : in  STD_LOGIC;
        SYS_RST : in  STD_LOGIC;
        nSEL : out  STD_LOGIC_VECTOR(0 to 2);
        seg7_timing : in STD_LOGIC;
        seg_in1 : in  STD_LOGIC_VECTOR(0 to 3);
        seg_in2 : in  STD_LOGIC_VECTOR(0 to 3);
        seg_in3 : in STD_LOGIC_VECTOR(0 to 3);
        seg_data : out STD_LOGIC_VECTOR(0 to 3)
    );
end dynamic_ctrl;

architecture IMP of dynamic_ctrl is

    signal sel : STD_LOGIC_VECTOR(0 to 2);
    signal seg_data_w : STD_LOGIC_VECTOR(0 to 3);
    signal seg7_tim : STD_LOGIC;
    signal seg7_tim_reg : STD_LOGIC;

begin
    process(SYS_CLK)
    begin
        if SYS_CLK'event and SYS_CLK = '1' then
            if SYS_RST = '1' then
                seg7_tim_reg <= '0';
            else
                seg7_tim_reg <= seg7_timing; 
            end if;
        end if;
    end process;
    
    process(SYS_CLK)
    begin
        if SYS_CLK'event and SYS_CLK = '1' then
            if SYS_RST = '1' then 
                seg7_tim <= '0';
            else
                seg7_tim <= seg7_timing and (not seg7_tim_reg); 
            end if;
        end if;
    end process;    
    
    process(SYS_CLK)
    begin
        if SYS_CLK'event and SYS_CLK = '1' then
            if SYS_RST = '1' then
                sel <= "001";
            else
                if seg7_tim = '1' then
                    sel <= sel(1 to 2) & sel(0);
                end if;
            end if;
        end if;
    end process;

    process(SYS_CLK)
    begin
        if SYS_CLK'event and SYS_CLK = '1' then
            if SYS_RST = '1' then
                seg_data_w <= "0000";
            else
                if sel = "001" then
                    seg_data_w <= seg_in1;
                elsif sel = "010" then
                    seg_data_w <= seg_in2;
                elsif sel = "100" then
                    seg_data_w <= seg_in3;
                end if;
            end if;
        end if;
    end process;

    nSEL <= not sel;
    seg_data <= seg_data_w;
    
end IMP;

